==> sui-login-password-reset-1.24.0.tgz: package/lib/hooks/components/usePasswordResetFormState.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { useReducer } from 'react';
var usePasswordResetFormState = function usePasswordResetFormState() {
  var initialState = {
    email: '',
    isLoading: false,
    errorText: '',
    notification: {
      text: '',
      isError: false
    }
  };
  var reducer = function reducer(state, action) {
    switch (action.type) {
      case 'SET_EMAIL':
        return _extends({}, state, {
          email: action.payload,
          isLoading: false
        });
      case 'SET_NOTIFICATION':
        return _extends({}, state, {
          notification: {
            text: action.payload.text,
            isError: action.payload.isError
          },
          isLoading: false
        });
      case 'SET_LOADING':
        return _extends({}, state, {
          isLoading: action.payload
        });
      case 'SET_ERROR_TEXT':
        return _extends({}, state, {
          errorText: action.payload
        });
      default:
        return state;
    }
  };
  var _useReducer = useReducer(reducer, initialState),
    state = _useReducer[0],
    dispatch = _useReducer[1];

  // Action for each of the above
  var setEmail = function setEmail(email) {
    dispatch({
      type: 'SET_EMAIL',
      payload: email
    });
  };
  var setNotification = function setNotification(_ref) {
    var text = _ref.text,
      isError = _ref.isError;
    dispatch({
      type: 'SET_NOTIFICATION',
      payload: {
        text: text,
        isError: isError
      }
    });
  };
  var setIsLoading = function setIsLoading(isLoading) {
    dispatch({
      type: 'SET_LOADING',
      payload: isLoading
    });
  };
  var setErrorText = function setErrorText(errorText) {
    dispatch({
      type: 'SET_ERROR_TEXT',
      payload: errorText
    });
  };
  return {
    state: state,
    setEmail: setEmail,
    setNotification: setNotification,
    setIsLoading: setIsLoading,
    setErrorText: setErrorText
  };
};
export default usePasswordResetFormState;

==> sui-login-password-reset-1.37.0.tgz: package/lib/hooks/components/usePasswordResetFormState.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { useReducer } from 'react';
var usePasswordResetFormState = function usePasswordResetFormState() {
  var initialState = {
    email: '',
    isLoading: false,
    errorText: '',
    notification: {
      text: '',
      isError: false
    }
  };
  var reducer = function reducer(state, action) {
    switch (action.type) {
      case 'SET_EMAIL':
        return _extends({}, state, {
          email: action.payload.email,
          errorText: '',
          isLoading: false
        });
      case 'SET_NOTIFICATION':
        return _extends({}, state, {
          notification: {
            text: action.payload.text,
            isError: action.payload.isError
          },
          isLoading: false
        });
      case 'SET_LOADING':
        return _extends({}, state, {
          isLoading: action.payload
        });
      case 'SET_ERROR_TEXT':
        return _extends({}, state, {
          errorText: action.payload.errorText,
          isLoading: false
        });
      default:
        return state;
    }
  };
  var _useReducer = useReducer(reducer, initialState),
    state = _useReducer[0],
    dispatch = _useReducer[1];

  // Action for each of the above
  var setEmail = function setEmail(_ref) {
    var email = _ref.email;
    dispatch({
      type: 'SET_EMAIL',
      payload: {
        email: email
      }
    });
  };
  var setNotification = function setNotification(_ref2) {
    var text = _ref2.text,
      isError = _ref2.isError;
    dispatch({
      type: 'SET_NOTIFICATION',
      payload: {
        text: text,
        isError: isError
      }
    });
  };
  var setIsLoading = function setIsLoading(isLoading) {
    dispatch({
      type: 'SET_LOADING',
      payload: isLoading
    });
  };
  var setErrorText = function setErrorText(_ref3) {
    var errorText = _ref3.errorText;
    dispatch({
      type: 'SET_ERROR_TEXT',
      payload: {
        errorText: errorText
      }
    });
  };
  return {
    state: state,
    setEmail: setEmail,
    setErrorText: setErrorText,
    setNotification: setNotification,
    setIsLoading: setIsLoading
  };
};
export default usePasswordResetFormState;
